@@ -1,4 +1,3 @@
-# coding: utf-8
 # /*##########################################################################
 #
 # Copyright (c) 2004-2021 European Synchrotron Radiation Facility
@@ -31,8 +30,6 @@ The following QAction are available:
 - :class:`PixelIntensitiesHistoAction`
 """
 
-from __future__ import division
-
 __authors__ = ["V.A. Sole", "T. Vincent", "P. Knobel"]
 __date__ = "01/12/2020"
 __license__ = "MIT"
@@ -64,7 +61,7 @@ class _ElidedLabel(ElidedLabel):
 
     def sizeHint(self):
         hint = super().sizeHint()
-        nbchar = max(len(self.getText()), 12)
+        nbchar = max(len(self.text()), 12)
         width = self.fontMetrics().boundingRect('#' * nbchar).width()
         return qt.QSize(max(hint.width(), width), hint.height())
 
