@@ -1,7 +1,6 @@
-# coding: utf-8
 # /*##########################################################################
 #
-# Copyright (c) 2004-2021 European Synchrotron Radiation Facility
+# Copyright (c) 2004-2022 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,8 +23,6 @@
 # ###########################################################################*/
 """Matplotlib Plot backend."""
 
-from __future__ import division
-
 __authors__ = ["V.A. Sole", "T. Vincent, H. Payno"]
 __license__ = "MIT"
 __date__ = "21/12/2018"
@@ -33,7 +30,7 @@ __date__ = "21/12/2018"
 
 import logging
 import datetime as dt
-from typing import Tuple
+from typing import Tuple, Union
 import numpy
 
 from pkg_resources import parse_version as _parse_version
@@ -64,6 +61,7 @@ from . import BackendBase
 from .. import items
 from .._utils import FLOAT32_MINPOS
 from .._utils.dtime_ticklayout import calcTicks, bestFormatString, timestamp
+from ...qt import inspect as qt_inspect
 
 _PATCH_LINESTYLE = {
     "-": 'solid',
@@ -166,8 +164,13 @@ class NiceDateLocator(Locator):
             vmin, vmax = vmax, vmin
 
         # vmin and vmax should be timestamps (i.e. seconds since 1 Jan 1970)
-        dtMin = dt.datetime.fromtimestamp(vmin, tz=self.tz)
-        dtMax = dt.datetime.fromtimestamp(vmax, tz=self.tz)
+        try:
+            dtMin = dt.datetime.fromtimestamp(vmin, tz=self.tz)
+            dtMax = dt.datetime.fromtimestamp(vmax, tz=self.tz)
+        except ValueError:
+            _logger.warning("Data range cannot be displayed with time axis")
+            return []
+
         dtTicks, self._spacing, self._unit = \
             calcTicks(dtMin, dtMax, self.numTicks)
 
@@ -1220,7 +1223,11 @@ class BackendMatplotlib(BackendBase.BackendBase):
         """Compatibility wrapper for devicePixelRatioF"""
         return 1.
 
-    def _mplToQtPosition(self, x: float, y: float) -> Tuple[float, float]:
+    def _mplToQtPosition(
+        self,
+        x: Union[float,numpy.ndarray],
+        y: Union[float,numpy.ndarray]
+    ) -> Tuple[Union[float,numpy.ndarray], Union[float,numpy.ndarray]]:
         """Convert matplotlib "display" space coord to Qt widget logical pixel
         """
         ratio = self._getDevicePixelRatio()
@@ -1238,7 +1245,8 @@ class BackendMatplotlib(BackendBase.BackendBase):
 
     def dataToPixel(self, x, y, axis):
         ax = self.ax2 if axis == "right" else self.ax
-        displayPos = ax.transData.transform_point((x, y)).transpose()
+        points = numpy.transpose((x, y))
+        displayPos = ax.transData.transform(points).transpose()
         return self._mplToQtPosition(*displayPos)
 
     def pixelToData(self, x, y, axis):
@@ -1325,7 +1333,7 @@ class BackendMatplotlib(BackendBase.BackendBase):
         self._synchronizeForegroundColors()
 
 
-class BackendMatplotlibQt(FigureCanvasQTAgg, BackendMatplotlib):
+class BackendMatplotlibQt(BackendMatplotlib, FigureCanvasQTAgg):
     """QWidget matplotlib backend using a QtAgg canvas.
 
     It adds fast overlay drawing and mouse event management.
@@ -1516,6 +1524,10 @@ class BackendMatplotlibQt(FigureCanvasQTAgg, BackendMatplotlib):
         self._drawOverlays()
 
     def replot(self):
+        if not qt_inspect.isValid(self):
+            _logger.info("replot requested but widget no longer exists")
+            return
+
         with self._plot._paintContext():
             BackendMatplotlib._replot(self)
 
