@@ -1,6 +1,5 @@
-# coding: utf-8
 # /*##########################################################################
-# Copyright (C) 2016-2021 European Synchrotron Radiation Facility
+# Copyright (C) 2016-2022 European Synchrotron Radiation Facility
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -27,15 +26,21 @@ __authors__ = ["P. Knobel"]
 __license__ = "MIT"
 __date__ = "17/01/2018"
 
-from collections import OrderedDict
-import numpy
+
+from collections import defaultdict, OrderedDict
+from copy import deepcopy
+from io import BytesIO
 import os
 import tempfile
 import unittest
-import h5py
-from copy import deepcopy
 
-from collections import defaultdict
+import h5py
+import numpy
+try:
+    import pint
+except ImportError:
+    pint = None
+import pytest
 
 from silx.utils.testutils import LoggingValidator
 
@@ -48,6 +53,13 @@ from ..utils import is_link
 from ..utils import h5py_read_dataset
 
 
+@pytest.fixture
+def tmp_h5py_file():
+    with BytesIO() as buffer:
+        with h5py.File(buffer, mode="w") as h5file:
+            yield h5file
+
+
 def tree():
     """Tree data structure as a recursive nested dictionary"""
     return defaultdict(tree)
@@ -512,6 +524,22 @@ class TestDictToH5(H5DictTestCase):
         assert_append("replace")
 
 
+@pytest.mark.skipif(pint is None, reason="Require pint")
+def test_dicttoh5_pint(tmp_h5py_file):
+    ureg = pint.UnitRegistry()
+    treedict = {
+        "array_mm": pint.Quantity([1, 2, 3], ureg.mm),
+        "value_kg": 3 * ureg.kg,
+    }
+
+    dicttoh5(treedict, tmp_h5py_file)
+
+    result = h5todict(tmp_h5py_file)
+    assert set(treedict.keys()) == set(result.keys())
+    for key, value in treedict.items():
+        assert numpy.array_equal(result[key], value.magnitude)
+
+
 class TestH5ToDict(H5DictTestCase):
     def setUp(self):
         self.tempdir = tempfile.mkdtemp()
@@ -800,6 +828,22 @@ class TestDictToNx(H5DictTestCase):
         assert_append("replace", add_nx_class=True)
 
 
+@pytest.mark.skipif(pint is None, reason="Require pint")
+def test_dicttonx_pint(tmp_h5py_file):
+    ureg = pint.UnitRegistry()
+    treedict = {
+        "array_mm": pint.Quantity([1, 2, 3], ureg.mm),
+        "value_kg": 3 * ureg.kg,
+    }
+
+    dictdump.dicttonx(treedict, tmp_h5py_file)
+
+    result = dictdump.nxtodict(tmp_h5py_file)
+    for key, value in treedict.items():
+        assert numpy.array_equal(result[key], value.magnitude)
+        assert result[f"{key}@units"] == f"{value.units:~C}"
+
+
 class TestNxToDict(H5DictTestCase):
     def setUp(self):
         self.tempdir = tempfile.mkdtemp()
