@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 #    Project: silx
 #             https://github.com/silx-kit/silx
@@ -28,8 +27,6 @@
 """A general purpose library for manipulating 2D images in 1 or 3 colors 
 
 """
-from __future__ import absolute_import, print_function, with_statement, division
-
 
 __author__ = "Jerome Kieffer"
 __license__ = "MIT"
