@@ -1,4 +1,3 @@
-# coding: utf-8
 # /*##########################################################################
 #
 # Copyright (c) 2016-2021 European Synchrotron Radiation Facility
@@ -47,8 +46,6 @@ Functions:
 
 """
 
-from __future__ import absolute_import, print_function, division
-
 import sys
 
 import numpy
